@@ -1,5 +1,5 @@
 package Twitter::API;
-our $VERSION = '0.0102';
+our $VERSION = '0.0103';
 use 5.14.1;
 use Moo;
 use Carp;
@@ -91,7 +91,6 @@ has user_agent => (
     },
     handles => {
         send_request   => 'request',
-        simple_request => 'request',
     },
 );
 
@@ -120,7 +119,7 @@ sub request {
         extra_args  => \@_,
     });
 
-    $self->extract_synthetic_args($c);
+    $self->extract_options($c);
     $self->preprocess_args($c);
     $self->preprocess_url($c);
     $self->add_authorization($c);
@@ -133,7 +132,7 @@ sub request {
     return wantarray ? ( $c->result, $c ) : $c->result;
 }
 
-sub extract_synthetic_args {
+sub extract_options {
     my ( $self, $c ) = @_;
 
     my $args = $c->args;
@@ -148,6 +147,10 @@ sub preprocess_args {
     if ( $c->http_method eq 'GET' ) {
         $self->flatten_array_args($c->args);
     }
+
+    # If any of the args are arrayrefs, we'll infer it's multipart/form-data
+    $c->set_option(multipart_form_data => 1) if
+        $c->http_method eq 'POST' && !!grep ref, values %{ $c->args };
 }
 
 sub preprocess_url {
@@ -177,7 +180,7 @@ sub add_authorization {
         signature_method => 'HMAC-SHA1',
         timestamp        => time,
         nonce            => Digest::SHA::sha1_base64({} . time . $$ . rand),
-        extra_params     => $self->is_multipart($args) ? {} : $args,
+        extra_params     => $c->get_option('multipart_form_data') ? {} : $args,
     );
 
     $req->sign;
@@ -194,7 +197,7 @@ sub finalize_request {
     my $method = $c->http_method;
     $c->set_http_request(
         $method eq 'POST' ? (
-            $self->is_multipart($c->args) ? $self->finalize_multipart_post($c)
+            $c->get_option('multipart_form_data') ? $self->finalize_multipart_post($c)
             : $c->has_option('to_json')   ? $self->finalize_json_post($c)
             : $self->finalize_post($c)
         )
@@ -258,7 +261,7 @@ sub inflate_response {
         if ( $res->content_type eq 'application/json' ) {
             $data = $self->from_json($res->content);
         }
-        elsif ( $res->content_length == 0 ) {
+        elsif ( ( $res->content_length // 0 ) == 0 ) {
             # E.g., 200 OK from media/metadata/create
             $data = '';
         }
@@ -316,9 +319,6 @@ sub process_error_response {
     Twitter::API::Error->throw({ context => $_[1] });
 }
 
-# If any of the args are references, we'll assume it's a multipart request
-sub is_multipart { !!grep ref, values %{ $_[1] } }
-
 sub api_url_for {
     my $self = shift;
 
@@ -416,7 +416,7 @@ Twitter::API - A Twitter REST API library for Perl
 
 =head1 VERSION
 
-version 0.0102
+version 0.0103
 
 =head1 SYNOPSIS
 
